@@ -9,9 +9,6 @@ from mio.errors import UserError
 
 class Exception(Object):
 
-    def __repr__(self):
-        return "{0:s}({1:s})".format(self.type, self.value or "")
-
     @method("try")
     def tryEval(self, receiver, context, m, code):
         try:
