@@ -107,3 +107,9 @@ def test_block_repr_star_args_kwargs(mio):
 def test_block_repr_star_args_star_star_kwargs(mio):
     mio.eval("x = block(*args, **kwargs, args; kwargs)")
     assert repr(mio.eval("x")) == "block(*args, **kwargs)"
+
+
+def test_block_call(mio):
+    x = mio.eval("""x = block("foo")""")
+    assert mio.eval("x") == x
+    assert mio.eval("x()") == "foo"
