@@ -4,6 +4,16 @@ def test_error(mio):
     assert mio.eval("e message") == "FooBar!"
 
 
+def test_call(mio):
+    mio.eval("""e = Error("FooBar!")""")
+    assert mio.eval("e message == \"FooBar!\"")
+
+
+def test_repr(mio):
+    e = mio.eval("""Error clone("Foo", "FooBar!")""")
+    assert repr(e) == "Foo(FooBar!)"
+
+
 def test_exception(mio):
     mio.eval("e = Exception try(a + b)")
     assert mio.eval("e type") == "AttributeError"
