@@ -16,7 +16,7 @@ def today():
     ''')
 
     today = date.today().strftime("%B %d, %Y")
-    assert mio.eval("date today") == today
+    assert mio.eval("date today()") == today
 
     mio.eval("""del("date")""")
 
@@ -43,7 +43,7 @@ def foo():
 """)
     ''')
 
-    assert mio.eval("foo foo") == "Foobar!"
+    assert mio.eval("foo foo()") == "Foobar!"
     assert mio.eval("foo x") == 1
 
 
@@ -63,5 +63,26 @@ def foo():
     assert foo.name == "foo"
     assert foo.file == str(tmpdir.join("foo.py"))
 
-    assert mio.eval("foo foo") == "Foobar!"
+    assert mio.eval("foo foo()") == "Foobar!"
     assert mio.eval("foo x") == 1
+
+
+def test_ffi_importall(mio):
+    mio.eval('''
+date = FFI clone("date", """
+from datetime import date
+
+
+def foo():
+    return "foo"
+
+
+def today():
+    return date.today().strftime("%B %d, %Y")
+
+
+__all__ = ("today",)
+""")
+    ''')
+
+    assert mio.eval("date keys") == ["today"]
